@@ -15,3 +15,6 @@ class BitStringType(BitString):
     def create_field_list(self, per_bytes):
         decoded = decode_bitstring(self, per_bytes)
         return decoded
+
+    def to_dict(self, is_root=True):
+        return int(self.asBinary(), 2)
