@@ -12,3 +12,6 @@ class BooleanType(Boolean):
     def create_field_list(self, per_bytes):
         decoded = decode_boolean(self, per_bytes)
         return decoded
+
+    def to_dict(self, is_root=True):
+        return bool(self)
