@@ -1,4 +1,4 @@
-from pyasn1.type.univ import Choice
+from pyasn1.type.univ import Choice, noValue
 from asn1PERser.codec.per.encoder import encode_choice
 from asn1PERser.codec.per.decoder import decode_choice
 from asn1PERser.classes.types.constraint import NoConstraint
@@ -18,3 +18,11 @@ class ChoiceType(Choice):
     def create_field_list(self, per_bytes):
         decoded = decode_choice(self, per_bytes)
         return decoded
+
+    def to_dict(self, is_root=True):
+        for componentType, componentValue in self.items():
+            if componentValue is not noValue and componentValue.isValue:
+                value_dict = componentValue.to_dict(is_root=False)
+                if value_dict is not noValue:
+                    return {componentType: value_dict}
+                return {}
