@@ -15,3 +15,6 @@ class OctetStringType(OctetString):
     def create_field_list(self, per_bytes):
         decoded = decode_octetstring(self, per_bytes)
         return decoded
+
+    def to_dict(self, is_root=True):
+        return ''.join(format(byte, '02x') for byte in self.asNumbers())
